@@ -211,6 +211,14 @@ int32_t SPVM__Sys__defined(SPVM_ENV* env, SPVM_VALUE* stack) {
       ival = (int32_t)__solaris;
       lval = (int64_t)__solaris;
       dval = (double)__solaris;
+#   endif
+  }
+  else if (strcmp(macro_name, "__sun") == 0) {
+#   ifdef __sun
+      defined = 1;
+      ival = (int32_t)__sun;
+      lval = (int64_t)__sun;
+      dval = (double)__sun;
 #   endif
   }
   else {
